@@ -33,9 +33,9 @@ var NAVTREE =
       [ "Installing the binaries on Windows", "install.html#install_bin_windows", null ]
     ] ],
     [ "Getting started", "starting.html", [
-      [ "Step 0: Check if doxygen supports your programming/hardware description language", "starting.html#step0", null ],
+      [ "Step 0: Check if Doxygen supports your programming/hardware description language", "starting.html#step0", null ],
       [ "Step 1: Creating a configuration file", "starting.html#step1", null ],
-      [ "Step 2: Running doxygen", "starting.html#step2", [
+      [ "Step 2: Running Doxygen", "starting.html#step2", [
         [ "HTML output", "starting.html#html_out", null ],
         [ "LaTeX output", "starting.html#latex_out", null ],
         [ "RTF output", "starting.html#rtf_out", null ],
@@ -144,22 +144,22 @@ var NAVTREE =
       [ "Help, some/all of the members of my class / file / namespace are not documented?", "faq.html#fac_al", null ],
       [ "When I set EXTRACT_ALL to NO none of my functions are shown in the documentation.", "faq.html#faq_extract_all", null ],
       [ "My file with a custom extension is not parsed (properly) (anymore).", "faq.html#faq_ext_mapping", null ],
-      [ "How can I make doxygen ignore some code fragment?", "faq.html#faq_code", null ],
+      [ "How can I make Doxygen ignore some code fragment?", "faq.html#faq_code", null ],
       [ "How can I change what is after the #include in the class documentation?", "faq.html#faq_code_inc", null ],
       [ "How can I use tag files in combination with compressed HTML?", "faq.html#faq_chm", null ],
       [ "I don't like the quick index that is put above each HTML page, what do I do?", "faq.html#faq_html", null ],
       [ "The overall HTML output looks different, while I only wanted to use my own html header file", "faq.html#faq_html_header", null ],
-      [ "Why does doxygen use Qt?", "faq.html#faq_use_qt", null ],
+      [ "Why does Doxygen use Qt?", "faq.html#faq_use_qt", null ],
       [ "How can I exclude all test directories from my directory tree?", "faq.html#faq_excl_dir", null ],
       [ "Doxygen automatically generates a link to the class MyClass somewhere in the running text....", "faq.html#faq_class", null ],
-      [ "My favorite programming language is X. Can I still use doxygen?", "faq.html#faq_pgm_X", null ],
+      [ "My favorite programming language is X. Can I still use Doxygen?", "faq.html#faq_pgm_X", null ],
       [ "Help! I get the cryptic message \"input buffer overflow, can't enlarge buffer because scanner uses REJ...", "faq.html#faq_lex", null ],
       [ "When running make in the latex directory I get \"TeX capacity exceeded\". Now what?", "faq.html#faq_latex", null ],
       [ "Why are dependencies via STL classes not shown in the dot graphs?", "faq.html#faq_stl", null ],
       [ "I have problems getting the search engine to work with PHP5 and/or windows", "faq.html#faq_search", null ],
-      [ "Can I configure doxygen from the command line?", "faq.html#faq_cmdline", null ],
-      [ "How did doxygen get its name?", "faq.html#faq_name", null ],
-      [ "What was the reason to develop doxygen?", "faq.html#faq_why", null ],
+      [ "Can I configure Doxygen from the command line?", "faq.html#faq_cmdline", null ],
+      [ "How did Doxygen get its name?", "faq.html#faq_name", null ],
+      [ "What was the reason to develop Doxygen?", "faq.html#faq_why", null ],
       [ "How to prevent interleaved output", "faq.html#faq_bin", null ]
     ] ],
     [ "Troubleshooting", "trouble.html", [
@@ -233,6 +233,8 @@ var NAVTREE =
       [ "\\hideinheritancegraph", "commands.html#cmdhideinheritancegraph", null ],
       [ "\\groupgraph", "commands.html#cmdgroupgraph", null ],
       [ "\\hidegroupgraph", "commands.html#cmdhidegroupgraph", null ],
+      [ "\\showenumvalues", "commands.html#cmdshowenumvalues", null ],
+      [ "\\hideenumvalues", "commands.html#cmdhideenumvalues", null ],
       [ "\\qualifier <label> | \"(text)\"", "commands.html#cmdqualifier", null ],
       [ "\\category <name> [<header-file>] [<header-name>]", "commands.html#cmdcategory", null ],
       [ "\\class <name> [<header-file>] [<header-name>]", "commands.html#cmdclass", null ],
@@ -452,6 +454,9 @@ var NAVTREE =
     ] ],
     [ "Doxygen's Internals", "arch.html", null ],
     [ "Changelog", "changelog.html", [
+      [ "1.12 Series", "changelog.html#log_1_12", [
+        [ "Release 1.12.0", "changelog.html#log_1_12_0", null ]
+      ] ],
       [ "1.11 Series", "changelog.html#log_1_11", [
         [ "Release 1.11.0", "changelog.html#log_1_11_0", null ]
       ] ],
@@ -510,7 +515,7 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "additional.html",
-"commands.html#cmdskip"
+"commands.html#cmdshowinlinesource"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
